| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.ECR.Types.ListImagesFilter
Description
Documentation
data ListImagesFilter Source #
An object representing a filter on a ListImages operation.
See: newListImagesFilter smart constructor.
Constructors
| ListImagesFilter' | |
Instances
newListImagesFilter :: ListImagesFilter Source #
Create a value of ListImagesFilter with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:tagStatus:ListImagesFilter', listImagesFilter_tagStatus - The tag status with which to filter your ListImages results. You can
filter results based on whether they are TAGGED or UNTAGGED.
listImagesFilter_tagStatus :: Lens' ListImagesFilter (Maybe TagStatus) Source #
The tag status with which to filter your ListImages results. You can
filter results based on whether they are TAGGED or UNTAGGED.