| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.ECR.Types.RepositoryFilter
Description
Synopsis
Documentation
data RepositoryFilter Source #
The filter settings used with image replication. Specifying a repository filter to a replication rule provides a method for controlling which repositories in a private registry are replicated. If no repository filter is specified, all images in the repository are replicated.
See: newRepositoryFilter smart constructor.
Constructors
| RepositoryFilter' | |
Fields
| |
Instances
Arguments
| :: Text | |
| -> RepositoryFilterType | |
| -> RepositoryFilter |
Create a value of RepositoryFilter with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:filter':RepositoryFilter', repositoryFilter_filter - The repository filter details. When the PREFIX_MATCH filter type is
specified, this value is required and should be the repository name
prefix to configure replication for.
$sel:filterType:RepositoryFilter', repositoryFilter_filterType - The repository filter type. The only supported value is PREFIX_MATCH,
which is a repository name prefix specified with the filter parameter.
repositoryFilter_filter :: Lens' RepositoryFilter Text Source #
The repository filter details. When the PREFIX_MATCH filter type is
specified, this value is required and should be the repository name
prefix to configure replication for.
repositoryFilter_filterType :: Lens' RepositoryFilter RepositoryFilterType Source #
The repository filter type. The only supported value is PREFIX_MATCH,
which is a repository name prefix specified with the filter parameter.